EnumMap

Struct EnumMap 

pub struct EnumMap<Ids: MapEnum, T>(/* private fields */);
Array which using enum as index

Implementations

Source

impl<Ids: MapEnum, T> EnumMap<Ids, T>

pub const fn from_array(data: <Ids::Array as Array>::Map<T>) -> Self

Create map from array, recomand using map_new or map_enum!(if require const or move value) instead

pub const fn as_array(&self) -> &<Ids::Array as Array>::Map<T>

Returns a shared reference to the underlying array.

pub const fn as_array_mut(&mut self) -> &mut <Ids::Array as Array>::Map<T>

Returns a mutable reference to the underlying array.

pub const fn into_array(self) -> <Ids::Array as Array>::Map<T>

Consumes the enum map and returns the underlying array.

pub const fn remap<TIds: MapEnum<Array = Ids::Array>>( &self, ) -> &EnumMap<TIds, T>

Reinterprets the enum map as being indexed by a different enum type that shares the same underlying array.

pub const fn remap_mut<TIds: MapEnum<Array = Ids::Array>>( &mut self, ) -> &mut EnumMap<TIds, T>

Mutable version of remap.

pub fn map_new(map: impl FnMut(Ids::Discriminant) -> T) -> Self

Create map by mapping closure, map will call excctally once for each enum variant, using map_enum! instead if require const or move value

pub const fn map_as_ref<'a>(&'a self) -> EnumMap<Ids, &'a T>

Creates a new enum map where each element references the corresponding element in self.

pub const fn map_as_mut<'a>(&'a mut self) -> EnumMap<Ids, &'a mut T>

Creates a new enum map where each element mutably references the corresponding element in self.

pub const fn transparent_wrap<U: TransparentWrapper<T>>(self) -> EnumMap<Ids, U>

Wraps each element of the map in a TransparentWrapper, safe because the repr is identical.

pub const fn transparent_peel<U>(self) -> EnumMap<Ids, U>
where T: TransparentWrapper<U>,

Unwraps (peels) each element from a TransparentWrapper, safe because the repr is identical.

Source

impl<Ids: MapEnum + PlainMapEnum, T> EnumMap<Ids, T>

pub const fn cget(&self, index: &Ids) -> &T

Gets a reference to the element at the index given by the enum variant index. This is a const-compatible version of the Index trait.

pub const fn cget_mut(&mut self, index: &Ids) -> &mut T

Gets a mutable reference to the element at the index given by the enum variant index. This is a const-compatible version of the IndexMut trait.

Source

impl<Ids0: MapEnum<Discriminant: Clone>, Ids1: MapEnum, T> EnumMap<Ids0, EnumMap<Ids1, T>>

pub fn map_new2( map: impl FnMut(Ids0::Discriminant, Ids1::Discriminant) -> T, ) -> Self

Creates a 2-level enum map by invoking the closure for every combination of (Ids0, Ids1) variants.