pub struct EnumMap<Ids: MapEnum, T>(/* private fields */);Expand description
Array which using enum as index
Implementations
Sourceimpl<Ids: MapEnum, T> EnumMap<Ids, T>
impl<Ids: MapEnum, T> EnumMap<Ids, T>
Sourcepub const fn from_array(data: <Ids::Array as Array>::Map<T>) -> Self
pub const fn from_array(data: <Ids::Array as Array>::Map<T>) -> Self
Create map from array, recomand using map_new or map_enum!(if require const or move value) instead
Sourcepub const fn as_array(&self) -> &<Ids::Array as Array>::Map<T>
pub const fn as_array(&self) -> &<Ids::Array as Array>::Map<T>
Returns a shared reference to the underlying array.
Sourcepub const fn as_array_mut(&mut self) -> &mut <Ids::Array as Array>::Map<T>
pub const fn as_array_mut(&mut self) -> &mut <Ids::Array as Array>::Map<T>
Returns a mutable reference to the underlying array.
Sourcepub const fn into_array(self) -> <Ids::Array as Array>::Map<T>
pub const fn into_array(self) -> <Ids::Array as Array>::Map<T>
Consumes the enum map and returns the underlying array.
Sourcepub const fn remap<TIds: MapEnum<Array = Ids::Array>>(
&self,
) -> &EnumMap<TIds, T>
pub const fn remap<TIds: MapEnum<Array = Ids::Array>>( &self, ) -> &EnumMap<TIds, T>
Reinterprets the enum map as being indexed by a different enum type that shares the same underlying array.
Sourcepub const fn remap_mut<TIds: MapEnum<Array = Ids::Array>>(
&mut self,
) -> &mut EnumMap<TIds, T>
pub const fn remap_mut<TIds: MapEnum<Array = Ids::Array>>( &mut self, ) -> &mut EnumMap<TIds, T>
Mutable version of remap.
Sourcepub fn map_new(map: impl FnMut(Ids::Discriminant) -> T) -> Self
pub fn map_new(map: impl FnMut(Ids::Discriminant) -> T) -> Self
Create map by mapping closure, map will call excctally once for each enum variant, using map_enum! instead if require const or move value
Sourcepub const fn map_as_ref<'a>(&'a self) -> EnumMap<Ids, &'a T>
pub const fn map_as_ref<'a>(&'a self) -> EnumMap<Ids, &'a T>
Creates a new enum map where each element references the corresponding element in self.
Sourcepub const fn map_as_mut<'a>(&'a mut self) -> EnumMap<Ids, &'a mut T>
pub const fn map_as_mut<'a>(&'a mut self) -> EnumMap<Ids, &'a mut T>
Creates a new enum map where each element mutably references the corresponding element in self.
Sourcepub const fn transparent_wrap<U: TransparentWrapper<T>>(self) -> EnumMap<Ids, U>
pub const fn transparent_wrap<U: TransparentWrapper<T>>(self) -> EnumMap<Ids, U>
Wraps each element of the map in a TransparentWrapper, safe because the repr is identical.
Sourcepub const fn transparent_peel<U>(self) -> EnumMap<Ids, U>where
T: TransparentWrapper<U>,
pub const fn transparent_peel<U>(self) -> EnumMap<Ids, U>where
T: TransparentWrapper<U>,
Unwraps (peels) each element from a TransparentWrapper, safe because the repr is identical.